@@ -8,17 +8,15 @@
 */
 
 #include "glossaryview.h"
-
-#include "lokalize_debug.h"
-
 #include "catalog.h"
 #include "flowlayout.h"
 #include "glossary.h"
-#include "project.h"
-
 #include "glossarywindow.h"
+#include "project.h"
 #include "stemming.h"
 
+#include <KLocalizedString>
+
 #include <QDragEnterEvent>
 #include <QElapsedTimer>
 #include <QPushButton>
@@ -27,8 +25,6 @@
 #include <QStringBuilder>
 #include <QTime>
 
-#include <klocalizedstring.h>
-
 using namespace GlossaryNS;
 
 GlossaryView::GlossaryView(QWidget *parent, Catalog *catalog, const QVector<QAction *> &actions)
